@@ -2,7 +2,7 @@ package SpiderUA;
 
 require LWP::RobotUA;
 @ISA = qw(LWP::RobotUA);
-$VERSION = "0.9";
+$VERSION = "0.9.1";
 
 require HTTP::Response;
 
@@ -67,23 +67,27 @@ sub request
 {
     my($self, $request, $arg, $size) = @_;
 
+    # If this is the first request, we need to set the start_uri, but we
+    # don't want to set it until after the call to SUPER::request in case
+    # the request is redirected.
+    my $firstRequest = 0;
+    unless (exists $self->{'first_request_flagged'}) {
+        $firstRequest = 1;
+        $self->{'first_request_flagged'} = 1;
+    }
+
     my $res = $self->SUPER::request($request, $arg, $size);
 
-    unless (exists $self->{'start_uri'}) {
-        # The first time that the request method is called, a
-        # recursive call will be made to fetch robots.txt.
-        if ($request->url->path ne '/robots.txt') {
-            if (defined $res->request) {
-                $self->{'start_uri'} = $res->request->url->canonical;
-            } else {
-                $self->{'start_uri'} = $request->url->canonical;
-            }
-
-            if ($self->{'start_uri'}->path =~ m#(.*/)#s) {
-                $self->{'start_uri_base_path'} = $1;
-            }
+    if ($firstRequest) {
+        if (defined $res->request) {
+            $self->{'start_uri'} = $res->request->url->canonical;
+        } else {
+            $self->{'start_uri'} = $request->url->canonical;
         }
 
+        if ($self->{'start_uri'}->path =~ m#(.*/)#s) {
+            $self->{'start_uri_base_path'} = $1;
+        }
     }
 
     $res;
